import Vue from 'vue';
import VueRouter from 'vue-router';
import store from '@/store/index';
const jwt = require('jsonwebtoken');
const originalPush = VueRouter.prototype.push;
VueRouter.prototype.push = function push(location) {
  return originalPush.call(this, location).catch((err) => err);
};
Vue.use(VueRouter);
const adminMenu = [
  {
    path: '/admin/personal/user',
    meta: { title: '个人用户' },
    component: () => import('../views/admin/personal/user/index.vue'),
  },
  {
    path: '/admin/personal/expert',
    meta: { title: '专家用户' },
    component: () => import('../views/admin/personal/expert/index.vue'),
  },
  {
    path: '/admin/personal/psexpert',
    meta: { title: '评审专家' },
    component: () => import('../views/admin/personal/psexpert/index.vue'),
  },
  {
    path: '/admin/shape',
    meta: { title: '形式审查' },
    component: () => import('../views/admin/shape/index.vue'),
  },
  {
    path: '/admin/expertscore',
    meta: { title: '专家初审' },
    component: () => import('../views/admin/expertscore/index.vue'),
  },
  {
    path: '/admin/expertscore/expert',
    meta: { title: '专家初审-专家指派/评分' },
    component: () => import('../views/admin/expertscore/expert.vue'),
  },
  {
    path: '/admin/meeting',
    meta: { title: '专家会审' },
    component: () => import('../views/admin/meeting/index.vue'),
  },
  {
    path: '/admin/perfect',
    meta: { title: '资料完善' },
    component: () => import('../views/admin/perfect/index.vue'),
  },
  {
    path: '/admin/meeting/file',
    meta: { title: '会审文件下载' },
    component: () => import('../views/admin/meeting/file.vue'),
  },
  {
    path: '/admin/cert/file',
    meta: { title: '证书制作' },
    component: () => import('../views/admin/cert/file/index.vue'),
  },
  {
    path: '/admin/cert/grant',
    meta: { title: '证书发放' },
    component: () => import('../views/admin/cert/grant/index.vue'),
  },
  {
    path: '/admin/cert/issued',
    meta: { title: '证书归档' },
    component: () => import('../views/admin/cert/issued/index.vue'),
  },
  {
    path: '/admin/adminCertFile',
    meta: { title: '证书单独上传' },
    component: () => import('../views/admin/adminCertFile/index.vue'),
  },
];
const userMenu = [
  {
    path: '/user/my/now',
    meta: { title: '申报中' },
    component: () => import('../views/user/my/now/index.vue'),
  },
  {
    path: '/user/my/past',
    meta: { title: '已往申报' },
    component: () => import('../views/user/my/past/index.vue'),
  },
  {
    path: '/user/expertscore',
    meta: { title: '专家评分' },
    component: () => import('../views/user/expertscore/index.vue'),
  },
  {
    path: '/user/meeting',
    meta: { title: '专家会审' },
    component: () => import('../views/user/meeting/index.vue'),
  },
  {
    path: '/user/cert/file',
    meta: { title: '证书制作' },
    component: () => import('../views/user/cert/file/index.vue'),
  },
  {
    path: '/user/cert/grant',
    meta: { title: '待发证书' },
    component: () => import('../views/user/cert/grant/index.vue'),
  },
  {
    path: '/user/cert/issued',
    meta: { title: '已发证书' },
    component: () => import('../views/user/cert/issued/index.vue'),
  },
  {
    path: '/user/userCertFile',
    meta: { title: '证书资料管理' },
    component: () => import('../views/user/userCertFile/index.vue'),
  },
];
const expertMenu = [
  {
    path: '/expert/examine/review',
    meta: { title: '专家初评' },
    component: () => import('../views/expert/examine/review/index.vue'),
  },
  {
    path: '/expert/examine/meeting',
    meta: { title: '专家会审' },
    component: () => import('../views/expert/examine/meeting/index.vue'),
  },
];
const web = [
  {
    path: '/',
    redirect: '/adminCenter/homeIndex',
  },
  {
    path: '/login',
    name: 'login',
    meta: { title: '管理登录' },
    component: () => import('../views/login.vue'),
  },
  {
    path: '/register',
    meta: { title: '注册账号' },
    component: () => import('../views/register.vue'),
  },
  {
    path: '/adminCenter/homeIndex',
    name: 'adminCenter',
    component: () => import('@common/src/components/admin-frame/Home.vue'),
    children: [
      {
        path: '/adminCenter/homeIndex',
        name: 'admin_homeIndex',
        meta: { title: '首页' },
        component: () => import('../views/adminCenter/homeIndex/index.vue'),
      },
      {
        path: '/system/basic',
        meta: { title: '基本信息' },
        component: () => import('../views/system/basic/index.vue'),
      },
      {
        path: '/system/updatepd',
        meta: { title: '修改密码' },
        component: () => import('../views/system/updatepd/index.vue'),
      },
      ...adminMenu,
      ...userMenu,
      ...expertMenu,
      {
        path: '/common/index',
        meta: { title: '申报管理' },
        component: () => import('../views/common/index.vue'),
      },
      {
        path: '/common/info',
        meta: { title: '申报信息' },
        component: () => import('../views/common/info.vue'),
      },
      {
        path: '/common/file',
        meta: { title: '证书资料' },
        component: () => import('../views/common/file.vue'),
      },
      {
        path: '/common/idea',
        meta: { title: '审核意见' },
        component: () => import('../views/common/idea.vue'),
      },
      {
        path: '/common/exidea',
        meta: { title: '专家意见' },
        component: () => import('../views/common/exidea.vue'),
      },
      {
        path: '/common/certfile',
        meta: { title: '资料预览' },
        component: () => import('../views/common/certfile.vue'),
      },
    ],
  },
];
const routes = [...web];
const router = new VueRouter({
  mode: 'history',
  base: process.env.VUE_APP_ROUTER,
  routes,
});
router.beforeEach((to, from, next) => {
  document.title = `${to.meta.title} `;
  const token = sessionStorage.getItem('token');
  if (to.path == '/adminCenter/homeIndex') {
    if (!token) {
      next('/login');
    } else {
      let user = jwt.decode(token);
      store.commit('setUser', user, { root: true });
      next();
    }
  } else {
    let user = jwt.decode(token);
    store.commit('setUser', user, { root: true });
    next();
  }
});

export default router;
